#
# Makefile for wl_glue driver
#
-# Copyright (C) 2011 Jo-Philipp Wich <jow@openwrt.org>
+# Copyright (C) 2011 Jo-Philipp Wich <jo@mein.io>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
/*
* wl_glue.c: Broadcom WL support module providing a unified SSB/BCMA handling.
- * Copyright (C) 2011 Jo-Philipp Wich <jow@openwrt.org>
+ * Copyright (C) 2011 Jo-Philipp Wich <jo@mein.io>
*/
#include "wl_glue.h"
#include <linux/bcma/bcma.h>
#endif
-MODULE_AUTHOR("Jo-Philipp Wich (jow@openwrt.org)");
+MODULE_AUTHOR("Jo-Philipp Wich (jo@mein.io)");
MODULE_DESCRIPTION("Broadcom WL SSB/BCMA compatibility layer");
MODULE_LICENSE("GPL");
/*
* wl_glue.h: Broadcom WL support module providing a unified SSB/BCMA handling.
- * Copyright (C) 2011 Jo-Philipp Wich <jow@openwrt.org>
+ * Copyright (C) 2011 Jo-Philipp Wich <jo@mein.io>
*/
#include <linux/types.h>
PKG_LICENSE:=FSFULLR
PKG_LICENSE_FILES:=LICENSE
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
include $(INCLUDE_DIR)/package.mk
include $(INCLUDE_DIR)/host-build.mk
PKG_SOURCE:=libevent-$(PKG_VERSION)-stable.tar.gz
PKG_SOURCE_URL:=@SF/levent
PKG_MD5SUM:=c4c56f986aa985677ca1db89630a2e11
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_LICENSE:=BSD-3-Clause
PKG_FIXUP:=autoreconf
PKG_VERSION:=1.11.1
PKG_RELEASE:=3
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_SOURCE:=libiconv-$(PKG_VERSION).tar.gz
PKG_SOURCE_URL:=@GNU/libiconv
PKG_LICENSE:=LGPL-2.1
PKG_LICENSE_FILES:=LICENSE
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
include $(INCLUDE_DIR)/package.mk
include $(INCLUDE_DIR)/host-build.mk
ftp://ftp.netfilter.org/pub/libmnl
PKG_MD5SUM:=7d95fc3bea3365bc03c48e484224f65f
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_FIXUP:=autoreconf
PKG_INSTALL:=1
http://www.netfilter.org/projects/libnetfilter_conntrack/files/ \
ftp://ftp.netfilter.org/pub/libnetfilter_conntrack/
PKG_MD5SUM:=18cf80c4b339a3285e78822dbd4f08d7
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_FIXUP:=autoreconf
PKG_LICENSE:=GPL-2.0+
ftp://ftp.netfilter.org/pub/libnfnetlink/ \
http://mirrors.evolva.ro/netfilter.org/libnfnetlink/
PKG_MD5SUM:=98927583d2016a9fb1936fed992e2c5e
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_LICENSE:=GPL-2.0+
PKG_FIXUP:=autoreconf
PKG_SOURCE:=$(PKG_NAME)-$(PKG_VERSION).tar.gz
PKG_SOURCE_URL:=@SF/linux-diag
PKG_MD5SUM:=14e7dcd0436d2f49aa403f67e1ef7ddc
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_LICENSE:=LGPL-2.1
PKG_LICENSE_FILES:=COPYING cmd/GPL lib/LGPL
PKG_SOURCE_URL:=http://freeworld.thc.org/releases/
PKG_MD5SUM:=2975dd54be35b68c140eb2a6b8ef5e59
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
include $(INCLUDE_DIR)/package.mk
PKG_SOURCE_SUBDIR:=$(PKG_NAME)-$(PKG_VERSION)
PKG_SOURCE_VERSION:=6be3afd819a86136b51c5ae722ab48266187155b
PKG_SOURCE:=$(PKG_NAME)-$(PKG_VERSION)-$(PKG_SOURCE_VERSION).tar.gz
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_LICENSE:=GPL-2.0
PKG_LICENSE_FILES:=COPYING
PKG_SOURCE_URL:=http://media.luffy.cx/files/lldpd
PKG_MD5SUM:=ed0226129b0c90b3a45c273fe1aba8de
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_LICENSE:=ISC
PKG_FIXUP:=autoreconf
"uname -r", "uname -s" and "uname -m" results with the "UNAME_R", "UNAME_S"
and "UNAME_M" environment variables.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/configure
+++ b/configure
The patch originated from the Debian project.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/ipcp.c
+++ b/pppd/ipcp.c
This patch closes the descriptor if it is already open when establishing a
new connection. It originated from the Debian project.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/sys-linux.c
+++ b/pppd/sys-linux.c
This patch changes to code to allways uncondiationally call
create_linkpidfile(), it originated from the Debian project.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/main.c
+++ b/pppd/main.c
The patch originated from the Debian project.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/chap-new.c
+++ b/pppd/chap-new.c
The patch originated from the Debain project.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/plugins/pppoatm/pppoatm.c
+++ b/pppd/plugins/pppoatm/pppoatm.c
The patch originated from the Debian project.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/ipcp.c
+++ b/pppd/ipcp.c
The patch originated from the Debian project.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/main.c
+++ b/pppd/main.c
This patch adjusts a number defaults to properly match the OpenWrt environment.
It is not intended for upstream.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/Makefile.linux
+++ b/pppd/Makefile.linux
This is a forward ported version of ppp-2.4.3-mppe-mppc-1.1.patch.gz found on
http://mppe-mppc.alphacron.de/ .
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/include/linux/ppp-comp.h
+++ b/include/linux/ppp-comp.h
itself. This patch removes the "-s" (strip) switch from all "install" commands
in order to install unstripped binaries into the destination prefix.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/chat/Makefile.linux
+++ b/chat/Makefile.linux
separate COPTS variable so that it is easier to override optimizations from
the environment.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/plugins/radius/Makefile.linux
+++ b/pppd/plugins/radius/Makefile.linux
This patch removes the exponential timeout increase between PADO or PADS
discovery attempts.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/plugins/rp-pppoe/discovery.c
+++ b/pppd/plugins/rp-pppoe/discovery.c
This patch implements periodic clock checking to look for time warps, if one
is detected, the internal counters are adjusted accordingly.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/main.c
+++ b/pppd/main.c
option value. Without this patch pppd would advertise a different MTU value
compared to what is set on the local interface in some cases.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/lcp.c
+++ b/pppd/lcp.c
pppd to react properly on errors, e.g. only redial (relaunch pppd) if there
was a hangup, but not if the CHAP authentication failed.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/main.c
+++ b/pppd/main.c
This patch adds some flags to required to properly link libpcap within the
OpenWrt environment.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/Makefile.linux
+++ b/pppd/Makefile.linux
"precompiled-active-filter" specifies a filter file containing rules to match
packets which are treated as active.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/Makefile.linux
+++ b/pppd/Makefile.linux
allocated pppX device immediately after it has been created to the requested
interface name.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/main.c
+++ b/pppd/main.c
This patch makes pppd fill out the rt_dev field so that only own default
routes are ever matched.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/sys-linux.c
+++ b/pppd/sys-linux.c
This patch addresses the issue by filling in the peer address as gateway
when generating the default route entry.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/sys-linux.c
+++ b/pppd/sys-linux.c
This patch removes the runtime kernel feature checks.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/sys-linux.c
+++ b/pppd/sys-linux.c
On many embedded systems there is not enough space to record PPP session
information to the permanent storage, therfore remove this option.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/pppd.h
+++ b/pppd/pppd.h
Many uClibc based environments lack wtmp and utmp support, therfore remove
the code updating the wtmp information.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/sys-linux.c
+++ b/pppd/sys-linux.c
Remove a number of historical protocol entries from pppd's builtin list, this
reduced the binary size without loss of features.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/main.c
+++ b/pppd/main.c
does not support multilink, so that controlling programs can unconditionally
pass it to pppd regardless of the compile time features.
-Signed-off-by: Jo-Philipp Wich <jow@openwrt.org>
+Signed-off-by: Jo-Philipp Wich <jo@mein.io>
--- a/pppd/options.c
+++ b/pppd/options.c
#
-# Copyright (C) 2010-2015 Jo-Philipp Wich <jow@openwrt.org>
+# Copyright (C) 2010-2015 Jo-Philipp Wich <jo@mein.io>
#
# This is free software, licensed under the GNU General Public License v2.
# See /LICENSE for more information.
http://mirrors.evolva.ro/netfilter.org/conntrack-tools
PKG_MD5SUM:=966a5d8f846ddf5304bcd12685c0707f
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_LICENSE:=GPL-2.0
PKG_FIXUP:=autoreconf
PKG_SOURCE_URL:=http://www.inet.no/dante/files/
PKG_MD5SUM:=68c2ce12119e12cea11a90c7a80efa8f
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_LICENSE:=BSD-4-Clause
PKG_FIXUP:=autoreconf
PKG_SOURCE_URL:=http://www.ex-parrot.com/~pdw/iftop/download
PKG_MD5SUM:=7e6decb4958e8a4890cccac335239f24
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_LICENSE:=GPL-2.0
include $(INCLUDE_DIR)/package.mk
PKG_SOURCE_URL:=http://ipset.netfilter.org
PKG_MD5SUM:=8831b8f01458bf2abacc222884195a62
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_LICENSE:=GPL-2.0
PKG_FIXUP:=autoreconf
PKG_SOURCE_URL:=http://www.skbuff.net/iputils
PKG_MD5SUM:=a36c25e9ec17e48be514dc0485e7376c
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_LICENSE:=GPL-2.0+
PKG_BUILD_DEPENDS:=sysfsutils
#
-# Copyright (C) 2012 Jo-Philipp Wich <jow@openwrt.org>
+# Copyright (C) 2012 Jo-Philipp Wich <jo@mein.io>
#
# This is free software, licensed under the Apache 2 license.
#
SECTION:=utils
CATEGORY:=Utilities
TITLE:=Simple radiotap capture utility
- MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+ MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
endef
define Package/iwcap/description
/*
* iwcap.c - A simply radiotap capture utility outputting pcap dumps
*
- * Copyright 2012 Jo-Philipp Wich <jow@openwrt.org>
+ * Copyright 2012 Jo-Philipp Wich <jo@mein.io>
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
#
-# Copyright (C) 2010-2016 Jo-Philipp Wich <jow@openwrt.org>
+# Copyright (C) 2010-2016 Jo-Philipp Wich <jo@mein.io>
#
# This is free software, licensed under the GPL 2 license.
#
PKG_SOURCE_SUBDIR:=$(PKG_NAME)-$(PKG_VERSION)
PKG_SOURCE_VERSION:=e4aca3910dff532ed878d0ceaf1ab6e8ad7719bf
PKG_SOURCE:=$(PKG_NAME)-$(PKG_VERSION)-$(PKG_SOURCE_VERSION).tar.gz
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_LICENSE:=GPL-2.0
PKG_CONFIG_DEPENDS := \
#
-# Copyright (C) 2012 Jo-Philipp Wich <jow@openwrt.org>
+# Copyright (C) 2012 Jo-Philipp Wich <jo@mein.io>
#
# This is free software, licensed under the Apache 2 license.
#
SECTION:=utils
CATEGORY:=Utilities
TITLE:=Simple IPv4/IPv6 address calculator
- MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+ MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
endef
define Package/owipcalc/description
/*
* owipcalc - OpenWrt IP Calculator
*
- * Copyright (C) 2012 Jo-Philipp Wich <jow@openwrt.org>
+ * Copyright (C) 2012 Jo-Philipp Wich <jo@mein.io>
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
SECTION:=utils
CATEGORY:=Base system
TITLE:=Simple DNS resolver with configurable timeout
- MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+ MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
endef
define Package/resolveip/description
/*
* Based on code found at https://dev.openwrt.org/ticket/4876 .
* Extended by Jo-Philipp Wich <jow@openwrt.org> for use in OpenWrt.
*
* You may use this program under the terms of the GPLv2 license.
*/
PKG_BUILD_PARALLEL:=1
PKG_CHECK_FORMAT_SECURITY:=0
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_LICENSE:=GPL-2.0
PKG_FIXUP:=autoreconf
PKG_LICENSE:=GPL-2.0
PKG_LICENSE_FILES:=COPYING
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_FLAGS := nonshared
PKG_CONFIG_DEPENDS := CONFIG_SIGNED_PACKAGES
PKG_SOURCE_SUBDIR:=$(PKG_NAME)
PKG_SOURCE_VERSION:=73aea9b8b621a1ce034bc6ee00c9d058a40c8a3d
PKG_SOURCE:=$(PKG_NAME)-$(PKG_VERSION)-$(PKG_SOURCE_VERSION).tar.gz
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_LICENSE:=ISC
PKG_LICENSE_FILES:=
PKG_SOURCE:=$(PKG_NAME)-$(PKG_VERSION)-$(PKG_SOURCE_VERSION).tar.gz
CMAKE_INSTALL:=1
-PKG_MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+PKG_MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
PKG_LICENSE:=ISC
include $(INCLUDE_DIR)/package.mk
CATEGORY:=Languages
TITLE:=Lua programming language
URL:=http://www.lua.org/
- MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+ MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
endef
define Package/lua/Default/description
#
-# Copyright (C) 2010-2015 Jo-Philipp Wich <jow@openwrt.org>
+# Copyright (C) 2010-2015 Jo-Philipp Wich <jo@mein.io>
#
# This is free software, licensed under the GNU General Public License v2.
# See /LICENSE for more information.
SECTION:=utils
CATEGORY:=Utilities
TITLE:=X.509 certificate generator (using PolarSSL)
- MAINTAINER:=Jo-Philipp Wich <jow@openwrt.org>
+ MAINTAINER:=Jo-Philipp Wich <jo@mein.io>
DEPENDS:=+libpolarssl
endef
#
# Script to install host system binaries along with required libraries.
#
-# Copyright (C) 2012-2013 Jo-Philipp Wich <jow@openwrt.org>
+# Copyright (C) 2012-2013 Jo-Philipp Wich <jo@mein.io>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# Script for various external toolchain tasks, refer to
# the --help output for more information.
#
-# Copyright (C) 2012 Jo-Philipp Wich <jow@openwrt.org>
+# Copyright (C) 2012 Jo-Philipp Wich <jo@mein.io>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
#!/usr/bin/env perl
#
# srecimage.pl - script to convert a binary image into srec
-# Copyright (c) 2015 - Jo-Philipp Wich <jow@openwrt.org>
+# Copyright (c) 2015 - Jo-Philipp Wich <jo@mein.io>
#
# This script is in the public domain.
+/*
+ * Implements a dummy match to allow attaching IDs to rules
+ *
-+ * 2014-08-01 Jo-Philipp Wich <jow@openwrt.org>
++ * 2014-08-01 Jo-Philipp Wich <jo@mein.io>
+ */
+
+#include <linux/module.h>
+#include <linux/netfilter/x_tables.h>
+#include <linux/netfilter/xt_id.h>
+
-+MODULE_AUTHOR("Jo-Philipp Wich <jow@openwrt.org>");
++MODULE_AUTHOR("Jo-Philipp Wich <jo@mein.io>");
+MODULE_DESCRIPTION("Xtables: No-op match which can be tagged with a 32bit ID");
+MODULE_LICENSE("GPL");
+MODULE_ALIAS("ipt_id");
+/*
+ * Implements a dummy match to allow attaching IDs to rules
+ *
-+ * 2014-08-01 Jo-Philipp Wich <jow@openwrt.org>
++ * 2014-08-01 Jo-Philipp Wich <jo@mein.io>
+ */
+
+#include <linux/module.h>
+#include <linux/netfilter/x_tables.h>
+#include <linux/netfilter/xt_id.h>
+
-+MODULE_AUTHOR("Jo-Philipp Wich <jow@openwrt.org>");
++MODULE_AUTHOR("Jo-Philipp Wich <jo@mein.io>");
+MODULE_DESCRIPTION("Xtables: No-op match which can be tagged with a 32bit ID");
+MODULE_LICENSE("GPL");
+MODULE_ALIAS("ipt_id");
+/*
+ * Implements a dummy match to allow attaching IDs to rules
+ *
-+ * 2014-08-01 Jo-Philipp Wich <jow@openwrt.org>
++ * 2014-08-01 Jo-Philipp Wich <jo@mein.io>
+ */
+
+#include <linux/module.h>
+#include <linux/netfilter/x_tables.h>
+#include <linux/netfilter/xt_id.h>
+
-+MODULE_AUTHOR("Jo-Philipp Wich <jow@openwrt.org>");
++MODULE_AUTHOR("Jo-Philipp Wich <jo@mein.io>");
+MODULE_DESCRIPTION("Xtables: No-op match which can be tagged with a 32bit ID");
+MODULE_LICENSE("GPL");
+MODULE_ALIAS("ipt_id");
@@
/*
* Based on code found at https://dev.openwrt.org/ticket/4876 .
- * Extended by Jo-Philipp Wich <jow@openwrt.org> for use in OpenWrt.
+ * Extended by Jo-Philipp Wich <jo@mein.io> for use in OpenWrt.
*
* You may use this program under the terms of the GPLv2 license.